namespace elm { namespace interface { 
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<void>::type Atspi_Component::size_get( ::efl::eolian::out_traits<int>::type w,  ::efl::eolian::out_traits<int>::type h) const
{
   int __out_param_w = {};
   int __out_param_h = {};
    ::elm_interface_atspi_component_size_get(this->_eo_ptr()
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(h, __out_param_h);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Component::size_set( ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_component_size_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<int>::type Atspi_Component::layer_get() const
{
   int __return_value =  ::elm_interface_atspi_component_layer_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<double>::type Atspi_Component::alpha_get() const
{
   double __return_value =  ::elm_interface_atspi_component_alpha_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<int>::type Atspi_Component::z_order_get() const
{
   int __return_value =  ::elm_interface_atspi_component_z_order_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<void>::type Atspi_Component::extents_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y,  ::efl::eolian::out_traits<int>::type w,  ::efl::eolian::out_traits<int>::type h) const
{
   int __out_param_x = {};
   int __out_param_y = {};
   int __out_param_w = {};
   int __out_param_h = {};
    ::elm_interface_atspi_component_extents_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      , & __out_param_x
      , & __out_param_y
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(h, __out_param_h);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Component::extents_set( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_component_extents_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<void>::type Atspi_Component::position_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y) const
{
   int __out_param_x = {};
   int __out_param_y = {};
    ::elm_interface_atspi_component_position_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Component::position_set( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_component_position_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Component::contains( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_component_contains(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Component::focus_grab() const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_component_focus_grab(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::eo::Base>::type Atspi_Component::accessible_at_point_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y) const
{
    ::Eo_Base* __return_value =  ::elm_interface_atspi_component_accessible_at_point_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::eo::Base>::type>(__return_value);
}
#endif
} } 
namespace eo_cxx {
namespace elm { namespace interface { 
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<void>::type Atspi_Component::size_get( ::efl::eolian::out_traits<int>::type w,  ::efl::eolian::out_traits<int>::type h) const
{
   int __out_param_w = {};
   int __out_param_h = {};
    ::elm_interface_atspi_component_size_get(this->_eo_ptr()
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(h, __out_param_h);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Component::size_set( ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_component_size_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<int>::type Atspi_Component::layer_get() const
{
   int __return_value =  ::elm_interface_atspi_component_layer_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<double>::type Atspi_Component::alpha_get() const
{
   double __return_value =  ::elm_interface_atspi_component_alpha_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<int>::type Atspi_Component::z_order_get() const
{
   int __return_value =  ::elm_interface_atspi_component_z_order_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<void>::type Atspi_Component::extents_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y,  ::efl::eolian::out_traits<int>::type w,  ::efl::eolian::out_traits<int>::type h) const
{
   int __out_param_x = {};
   int __out_param_y = {};
   int __out_param_w = {};
   int __out_param_h = {};
    ::elm_interface_atspi_component_extents_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      , & __out_param_x
      , & __out_param_y
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(h, __out_param_h);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Component::extents_set( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y,  ::efl::eolian::in_traits<int>::type w,  ::efl::eolian::in_traits<int>::type h) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_component_extents_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(w)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(h));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<void>::type Atspi_Component::position_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y) const
{
   int __out_param_x = {};
   int __out_param_y = {};
    ::elm_interface_atspi_component_position_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Component::position_set( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_component_position_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Component::contains( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_component_contains(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Component::focus_grab() const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_component_focus_grab(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_COMPONENT_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::eo::Base>::type Atspi_Component::accessible_at_point_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y) const
{
    ::Eo_Base* __return_value =  ::elm_interface_atspi_component_accessible_at_point_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::eo::Base>::type>(__return_value);
}
#endif
inline elm::interface::Atspi_Component::operator ::elm::interface::Atspi_Component() const { return *static_cast< ::elm::interface::Atspi_Component const*>(static_cast<void const*>(this)); }
inline elm::interface::Atspi_Component::operator ::elm::interface::Atspi_Component&() { return *static_cast< ::elm::interface::Atspi_Component*>(static_cast<void*>(this)); }
inline elm::interface::Atspi_Component::operator ::elm::interface::Atspi_Component const&() const { return *static_cast< ::elm::interface::Atspi_Component const*>(static_cast<void const*>(this)); }
} } }

